package com.mopub.mobileads;

import android.app.Activity;
import android.content.Context;
import android.text.TextUtils;
import android.util.Log;
import android.widget.RelativeLayout;

import com.pokkt.PokktAds;
import com.pokkt.sdk.banners.PokktBannerView;

import java.util.Map;

public class PokktMoPubCustomBanner extends CustomEventBanner implements PokktAds.Banner.BannerAdDelegate {

    private final String TAG = "PokktMoPubWrapperBanner";
    private CustomEventBannerListener customEventBannerListener;
    private PokktBannerView pokktBannerView;
    private boolean isDebug = true;

    @Override
    protected void loadBanner(Context context, CustomEventBannerListener listener, Map<String, Object> localExtras, Map<String, String> serverExtras) {
        String appId = "";
        String secKey = "";
        if (extrasAreValid(serverExtras)) {
            appId = serverExtras.get("POKKT_APP_ID");
            secKey = serverExtras.get("POKKT_SEC_KEY");
        }

        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(secKey)) {
            Log.e(TAG, "Invalid details. Abort request");
            return;
        }
        //third party user id
        String thirdPartyUserid = "";
        if (serverExtras.containsKey("POKKT_THIRD_PARTY_USERID")) {
            thirdPartyUserid = serverExtras.get("POKKT_THIRD_PARTY_USERID");
        }
        if (TextUtils.isEmpty(thirdPartyUserid)) {
            thirdPartyUserid = "12345";
        }

        //debug
        String debug = "";
        if (serverExtras.containsKey("POKKT_DEBUG")) {
            debug = serverExtras.get("POKKT_DEBUG");
        }
        if (TextUtils.isEmpty(debug)) {
            debug = "true";
        }
        isDebug = debug.equalsIgnoreCase("true");

        //Screen name
        String screenName = "";
        if (serverExtras.containsKey("POKKT_SCREEN_NAME")) {
            screenName = serverExtras.get("POKKT_SCREEN_NAME");
        }
        if (TextUtils.isEmpty(screenName)) {
            screenName = "Default";
        }

        if (isDebug) {
            Log.i(TAG, "loadBanner ");
        }
        customEventBannerListener = listener;

        PokktAds.setPokktConfig(appId, secKey, (Activity) context);
        PokktAds.setThirdPartyUserId(thirdPartyUserid);
        PokktAds.Debugging.shouldDebug(context, isDebug);

        PokktAds.Banner.setDelegate(this);

        int width = 300;
        try {
            if (localExtras.containsKey("com_mopub_ad_width")) {
                width = (Integer) localExtras.get("com_mopub_ad_width");
            }
        } catch (Throwable t) {
            if (isDebug) {
                Log.e(TAG, "failed to parse width ");
            }
        }
        int height = 50;
        try {
            if (localExtras.containsKey("com_mopub_ad_height")) {
                height = (Integer) localExtras.get("com_mopub_ad_height");
            }
        } catch (Throwable t) {
            if (isDebug) {
                Log.e(TAG, "failed to parse height ");
            }
        }
        pokktBannerView = new PokktBannerView(context);
        RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(width, height);
        pokktBannerView.setLayoutParams(layoutParams);

        PokktAds.Banner.loadBanner(screenName, pokktBannerView);
    }

    private boolean extrasAreValid(Map<String, String> extras) {
        return extras.containsKey("POKKT_APP_ID")
                && extras.containsKey("POKKT_SEC_KEY");
    }

    @Override
    protected void onInvalidate() {
        if (isDebug) {
            Log.i(TAG, " Destroy banner ad");
        }
        if (pokktBannerView != null) {
            PokktAds.Banner.destroy(pokktBannerView);
            pokktBannerView = null;
        }
    }

    @Override
    public void bannerLoaded(String s) {
        if (isDebug) {
            Log.i(TAG, "bannerLoaded ");
        }
        customEventBannerListener.onBannerLoaded(pokktBannerView);
    }

    @Override
    public void bannerLoadFailed(String s, String s1) {
        if (isDebug) {
            Log.i(TAG, "bannerLoadFailed " + s1);
        }
        customEventBannerListener.onBannerFailed(MoPubErrorCode.NO_FILL);
    }
}
