package com.mopub.mobileads;

import android.app.Activity;
import android.content.Context;
import android.text.TextUtils;
import android.util.Log;

import com.pokkt.PokktAds;

import java.util.Map;

public class PokktMoPubCustomInterstitial extends CustomEventInterstitial implements PokktAds.Interstitial.InterstitialDelegate, PokktAds.VideoAd.VideoAdDelegate {

    private final String TAG = "PokktMoPubWrapperInter";
    private CustomEventInterstitialListener customEventInterstitialListener = null;
    private String screenName = "Default";
    private boolean isDebug = true;
    private int isAdAvailable = 0;//1 video ad available, 2 interstitial available

    @Override
    protected void loadInterstitial(final Context context,
                                    final CustomEventInterstitialListener listener,
                                    final Map<String, Object> localExtras,
                                    final Map<String, String> serverExtras) {
        if (context == null) {
            listener.onInterstitialFailed(MoPubErrorCode.NETWORK_INVALID_STATE);
            return;
        }


        String appId = "";
        String secKey = "";
        if (extrasAreValid(serverExtras)) {
            appId = serverExtras.get("POKKT_APP_ID");
            secKey = serverExtras.get("POKKT_SEC_KEY");
        }

        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(secKey)) {
            if (isDebug) {
                Log.e(TAG, "Invalid details. Abort request");
            }
            return;
        }

        String thirdPartyUserid = "";
        if (serverExtras.containsKey("POKKT_THIRD_PARTY_USERID")) {
            thirdPartyUserid = serverExtras.get("POKKT_THIRD_PARTY_USERID");
        }
        if (TextUtils.isEmpty(thirdPartyUserid)) {
            thirdPartyUserid = "12345";
        }

        //debug
        String debug = "";
        if (serverExtras.containsKey("POKKT_DEBUG")) {
            debug = serverExtras.get("POKKT_DEBUG");
        }
        if (TextUtils.isEmpty(debug)) {
            debug = "true";
        }
        isDebug = debug.equalsIgnoreCase("true");

        //Screen name
        if (serverExtras.containsKey("POKKT_SCREEN_NAME")) {
            screenName = serverExtras.get("POKKT_SCREEN_NAME");
        }
        if (TextUtils.isEmpty(screenName)) {
            screenName = "Default";
        }

        if (isDebug) {
            Log.i(TAG, "loadInterstitial ");
        }

        customEventInterstitialListener = listener;
        PokktAds.setPokktConfig(appId, secKey, (Activity) context);
        PokktAds.setThirdPartyUserId(thirdPartyUserid);
        PokktAds.Debugging.shouldDebug(context, isDebug);

        PokktAds.Interstitial.setDelegate(this);
        PokktAds.VideoAd.setDelegate(this);

        //first try video.
        PokktAds.VideoAd.cacheNonRewarded(screenName);
    }

    private boolean extrasAreValid(Map<String, String> extras) {
        return extras.containsKey("POKKT_APP_ID")
                && extras.containsKey("POKKT_SEC_KEY");
    }

    @Override
    protected void onInvalidate() {
    }

    @Override
    protected void showInterstitial() {
        if (isDebug) {
            Log.i(TAG, "showInterstitial ");
        }
        if (isAdAvailable == 1) {
            PokktAds.VideoAd.showNonRewarded(screenName);
        } else {
            PokktAds.Interstitial.showNonRewarded(screenName);
        }
    }

    @Override
    public void interstitialCachingCompleted(String screenName, boolean isRewarded, double rewardValue) {
        if (isDebug) {
            Log.i(TAG, "interstitial cached ");
        }
        isAdAvailable = 2;
        customEventInterstitialListener.onInterstitialLoaded();
    }

    @Override
    public void interstitialCachingFailed(String screenName, boolean isRewarded, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, "Interstitial caching failed " + errorMessage);
        }
        isAdAvailable = 0;
        customEventInterstitialListener.onInterstitialFailed(MoPubErrorCode.NETWORK_NO_FILL);
    }

    @Override
    public void interstitialDisplayed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Interstitial displayed");
        }
        customEventInterstitialListener.onInterstitialShown();
    }

    @Override
    public void interstitialFailedToShow(String screenName, boolean isRewarded, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, "Interstitial failed to show " + errorMessage);
        }
        isAdAvailable = 0;
    }

    @Override
    public void interstitialClosed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Interstitial closed");
        }
        isAdAvailable = 0;
        customEventInterstitialListener.onInterstitialDismissed();
    }

    @Override
    public void interstitialSkipped(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Interstitial skipped");
        }
        isAdAvailable = 0;
    }

    @Override
    public void interstitialCompleted(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Interstitial completed");
        }
    }

    @Override
    public void interstitialGratified(String screenName, boolean isRewarded, double reward) {

    }

    @Override
    public void interstitialAvailabilityStatus(String screenName, boolean isRewarded, boolean isAdAvailable) {
        if (isDebug) {
            Log.i(TAG, "Interstitial available");
        }
    }

    @Override
    public void videoAdCachingCompleted(String screenName, boolean isRewarded, double rewardValue) {
        if (isDebug) {
            Log.i(TAG, "Video caching completed");
        }
        isAdAvailable = 1;
        customEventInterstitialListener.onInterstitialLoaded();
    }

    @Override
    public void videoAdCachingFailed(String screenName, boolean isRewarded, String errorMessage) {
        //try for non rewarded interstitial
        if (isDebug) {
            Log.i(TAG, "Video caching failed " + errorMessage);
        }
        PokktAds.Interstitial.cacheNonRewarded(screenName);
    }

    @Override
    public void videoAdDisplayed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Video displayed");
        }
        customEventInterstitialListener.onInterstitialShown();
    }

    @Override
    public void videoAdFailedToShow(String screenName, boolean isRewarded, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, "Video failed to show " + errorMessage);
        }
        isAdAvailable = 0;
    }

    @Override
    public void videoAdClosed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Video closed");
        }
        isAdAvailable = 0;
        customEventInterstitialListener.onInterstitialDismissed();
    }

    @Override
    public void videoAdSkipped(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Video skipped");
        }
        isAdAvailable = 0;
    }

    @Override
    public void videoAdCompleted(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Video completed");
        }
    }

    @Override
    public void videoAdGratified(String screenName, boolean isRewarded, double rewardValue) {

    }

    @Override
    public void videoAdAvailabilityStatus(String screenName, boolean isRewarded, boolean isAdAvailable) {

    }
}
