package com.mopub.mobileads;

import android.app.Activity;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.text.TextUtils;
import android.util.Log;

import com.mopub.common.LifecycleListener;
import com.mopub.common.MoPubReward;
import com.pokkt.PokktAds;

import java.util.Map;

/**
 * A custom event for showing AdColony rewarded videos.
 */
public class PokktMoPubCustomRewardedVideo extends CustomEventRewardedVideo implements LifecycleListener {
    private static final String TAG = "PokktMoPubWrapperVideo";

    private PokktListener pokktListener;
    private String screenName = "Default";
    private String thirdPartyUserid = "12345";
    private String rewardCurrency = "";
    private boolean isDebug = true;
    private boolean isVideoAvailable;

    @Nullable
    @Override
    public CustomEventRewardedVideoListener getVideoListenerForSdk() {
        return pokktListener;
    }

    @Nullable
    @Override
    public LifecycleListener getLifecycleListener() {
        return this;
    }

    @NonNull
    @Override
    public String getAdNetworkId() {
        if (isDebug) {
            Log.d(TAG, "get AdNetwork Id");
        }
        return thirdPartyUserid;
    }

    @Override
    protected void onInvalidate() {
        if (isDebug) {
            Log.d(TAG, "Rewarded video destroyed");
        }
    }

    @Override
    public boolean checkAndInitializeSdk(@NonNull final Activity launcherActivity,
                                         @NonNull final Map<String, Object> localExtras,
                                         @NonNull final Map<String, String> serverExtras) throws Exception {
        synchronized (PokktMoPubCustomRewardedVideo.class) {

            // Set up serverExtras
            String appId = "";
            String secKey = "";
            if (extrasAreValid(serverExtras)) {
                appId = serverExtras.get("POKKT_APP_ID");
                secKey = serverExtras.get("POKKT_SEC_KEY");
            }

            if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(secKey)) {
                if (isDebug) {
                    Log.e(TAG, "Invalid details. Abort request");
                }
                return false;
            }

            //third party user id
            String thirdPartyUserid = "";
            if (serverExtras.containsKey("POKKT_THIRD_PARTY_USERID")) {
                thirdPartyUserid = serverExtras.get("POKKT_THIRD_PARTY_USERID");
            }
            if (TextUtils.isEmpty(thirdPartyUserid)) {
                thirdPartyUserid = "12345";
            }

            //debug
            String debug = "";
            if (serverExtras.containsKey("POKKT_DEBUG")) {
                debug = serverExtras.get("POKKT_DEBUG");
            }
            if (TextUtils.isEmpty(debug)) {
                debug = "true";
            }
            isDebug = debug.equalsIgnoreCase("true");

            //Currency
            if (serverExtras.containsKey("POKKT_REWARD_NAME")) {
                rewardCurrency = serverExtras.get("POKKT_REWARD_NAME");
            }

            if (isDebug) {
                Log.i(TAG, "checkAndInitializeSdk ");
            }
            PokktAds.setPokktConfig(appId, secKey, launcherActivity);
            PokktAds.setThirdPartyUserId(thirdPartyUserid);
            PokktAds.Debugging.shouldDebug(launcherActivity, isDebug);

            pokktListener = new PokktListener();
            PokktAds.VideoAd.setDelegate(pokktListener);

            return true;
        }
    }

    @Override
    protected void loadWithSdkInitialized(@NonNull final Activity activity,
                                          @NonNull final Map<String, Object> localExtras,
                                          @NonNull final Map<String, String> serverExtras) throws Exception {

        if (isDebug) {
            Log.i(TAG, "loadWithSdkInitialized ");
        }
        //Screen name
        if (serverExtras.containsKey("POKKT_SCREEN_NAME")) {
            screenName = serverExtras.get("POKKT_SCREEN_NAME");
        }
        if (TextUtils.isEmpty(screenName)) {
            screenName = "Default";
        }

        PokktAds.VideoAd.cacheRewarded(screenName);
    }

    @Override
    public boolean hasVideoAvailable() {
        if (isDebug) {
            Log.i(TAG, "Checking video availability ");
        }
        return isVideoAvailable;
    }

    @Override
    public void showVideo() {
        if (isDebug) {
            Log.i(TAG, "showVideo");
        }
        PokktAds.VideoAd.showRewarded(screenName);
    }

    private boolean extrasAreValid(Map<String, String> extras) {
        return extras.containsKey("POKKT_APP_ID")
                && extras.containsKey("POKKT_SEC_KEY");
    }

    @Override
    public void onCreate(@NonNull Activity activity) {

    }

    @Override
    public void onStart(@NonNull Activity activity) {

    }

    @Override
    public void onPause(@NonNull Activity activity) {

    }

    @Override
    public void onResume(@NonNull Activity activity) {

    }

    @Override
    public void onRestart(@NonNull Activity activity) {

    }

    @Override
    public void onStop(@NonNull Activity activity) {

    }

    @Override
    public void onDestroy(@NonNull Activity activity) {

    }

    @Override
    public void onBackPressed(@NonNull Activity activity) {

    }

    private class PokktListener implements PokktAds.VideoAd.VideoAdDelegate, CustomEventRewardedVideoListener {
        @Override
        public void videoAdCachingCompleted(String screenName, boolean isRewarded, double rewardValue) {
            if (isDebug) {
                Log.i(TAG, "rewarded video cached");
            }
            PokktMoPubCustomRewardedVideo.this.isVideoAvailable = true;
            MoPubRewardedVideoManager.onRewardedVideoLoadSuccess(PokktMoPubCustomRewardedVideo.class, thirdPartyUserid);
        }

        @Override
        public void videoAdCachingFailed(String screenName, boolean isRewaded, String errorMessage) {
            if (isDebug) {
                Log.i(TAG, " video caching failed " + errorMessage);
            }
            PokktMoPubCustomRewardedVideo.this.isVideoAvailable = false;
            MoPubRewardedVideoManager.onRewardedVideoLoadFailure(PokktMoPubCustomRewardedVideo.class, thirdPartyUserid, MoPubErrorCode.NO_FILL);
        }

        @Override
        public void videoAdDisplayed(String screenName, boolean isRewarded) {
            if (isDebug) {
                Log.i(TAG, " video displayed");
            }
            MoPubRewardedVideoManager.onRewardedVideoStarted(PokktMoPubCustomRewardedVideo.class, thirdPartyUserid);
        }

        @Override
        public void videoAdFailedToShow(String screenName, boolean isRewarded, String errorMessage) {
            if (isDebug) {
                Log.i(TAG, " video failed to show " + errorMessage);
            }
            PokktMoPubCustomRewardedVideo.this.isVideoAvailable = false;
        }

        @Override
        public void videoAdClosed(String screenName, boolean isRewarded) {
            if (isDebug) {
                Log.i(TAG, " video closed");
            }
            PokktMoPubCustomRewardedVideo.this.isVideoAvailable = false;
            MoPubRewardedVideoManager.onRewardedVideoClosed(PokktMoPubCustomRewardedVideo.class, thirdPartyUserid);
        }

        @Override
        public void videoAdSkipped(String screenName, boolean isRewarded) {
            if (isDebug) {
                Log.i(TAG, " video skipped");
            }
        }

        @Override
        public void videoAdCompleted(String screenName, boolean isRewarded) {
            if (isDebug) {
                Log.i(TAG, " video completed");
            }
        }

        @Override
        public void videoAdGratified(String screenName, boolean isRewarded, final double rewardValue) {
            if (isDebug) {
                Log.i(TAG, " video gratified");
            }
            MoPubReward reward = MoPubReward.success(rewardCurrency, (int) rewardValue);
            MoPubRewardedVideoManager.onRewardedVideoCompleted(PokktMoPubCustomRewardedVideo.class, thirdPartyUserid, reward);
        }

        @Override
        public void videoAdAvailabilityStatus(String screenName, boolean isRewarded, boolean availability) {
            if (isDebug) {
                Log.i(TAG, " video available");
            }
        }
    }
}
